@@ -22,7 +22,6 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA
 #include "thumbnailgenerator.h"
 
 // Local
-#include "exiv2imageloader.h"
 #include "gwenview_lib_debug.h"
 #include "gwenviewconfig.h"
 #include "jpegcontent.h"
@@ -38,7 +37,6 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA
 #include <QBuffer>
 #include <QCoreApplication>
 #include <QImageReader>
-#include <QTransform>
 
 namespace Gwenview
 {
