@@ -36,7 +36,6 @@
 #include <QTemporaryFile>
 
 // KF
-#include <KIO/JobUiDelegate>
 #include <KIO/PreviewJob>
 #include <KJobWidgets>
 
@@ -405,6 +404,10 @@ QImage ThumbnailProvider::loadThumbnailFromCache() const
         return image;
     }
 
+    if (!QFileInfo::exists(mThumbnailPath)) {
+        return {};
+    }
+
     image = QImage(mThumbnailPath);
     int largeThumbnailGroup = mThumbnailGroup;
     while (image.isNull() && ++largeThumbnailGroup <= ThumbnailGroup::XXLarge) {
